<?php

use CodeIgniter\Router\RouteCollection;

// ✅ Enable CORS headers for all requests
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: GET, POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type, Authorization");

/**
 * @var RouteCollection $routes
 */

// ✅ Home Route
$routes->get('/', 'Home::index');

// ✅ Email Test
$routes->get('email-test', 'EmailTest::index');

// ✅ Registration Routes
$routes->group('auth', function ($routes) {
    $routes->get('register', 'Auth::register');
    $routes->post('processRegister', 'Auth::processRegister');

    // ✅ Login Routes
    $routes->get('login', 'Auth::login');
    $routes->post('processLogin', 'Auth::processLogin');

    // ✅ Email Verification
    $routes->get('verifyEmail/(:any)', 'Auth::verifyEmail/$1');

    // ✅ Forgot Password
    $routes->get('forgotPassword', 'Auth::forgotPassword');
    $routes->post('forgotPassword', 'Auth::processForgotPassword');

    // ✅ Reset Password
    $routes->get('resetPassword/(:any)', 'Auth::resetPassword/$1');
    $routes->post('processResetPassword/(:any)', 'Auth::processResetPassword/$1');
});

// ✅ Registration Success Page
$routes->get('register-success', 'Auth::registerSuccess');

// ✅ User Management
$routes->group('users', function ($routes) {
    $routes->get('edit/(:num)', 'Auth::editUser/$1'); // Admin Edit User
    $routes->post('update/(:num)', 'Auth::updateUser/$1'); // Admin Update User
});

// ✅ Profile Management
$routes->group('profile', function ($routes) {
    $routes->get('edit', 'Auth::editProfile'); // User Self-Edit
    $routes->post('update', 'Auth::updateProfile'); // Process Profile Update
});

// ✅ Dashboard
$routes->get('dashboard', 'DashboardController::index');

// ✅ Log Out
$routes->get('logout', 'Auth::logout');

// ✅ Form Builder
$routes->get('form-builder', 'FormBuilder::index');
$routes->get('form-builder-dev', 'FormBuilder::dev'); // Development Version

// ✅ Test Insert Route (Troubleshooting)
$routes->get('app-builder/testInsert', 'AppBuilder::testInsert');

// ✅ App Builder Routes
$routes->get('app-builder', 'AppBuilder::index');
$routes->post('save_app', 'AppBuilder::saveApp');

// ✅ Modules System Fix (for dynamic module files)
$routes->get('modules/(:any)', function ($moduleFile) {
    $filePath = APPPATH . 'Views/modules/' . $moduleFile;
    
    if (!file_exists($filePath)) {
        throw \CodeIgniter\Exceptions\PageNotFoundException::forPageNotFound();
    }
    
    return view('modules/' . $moduleFile);
});

// ✅ Dedicated Module Preview Route
$routes->get('module-preview/(:any)', 'ModulePreview::show/$1');

// ✅ Application Dynamic Path
$routes->get('apps/(:segment)', 'AppBuilder::loadApp/$1');

// ✅ File Upload Route
$routes->post('upload_logo', 'UploadController::uploadLogo');

// ✅ Autoload Test Route (Check if `app-creator/` is working)
$routes->get('autoloadtest', 'AutoloadTest::index');
