<?php
// modules/PageBreakModule.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

// Helper function if not already defined
if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class PageBreakModule {
    private $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('pageBreak_');
        $this->settings = array_merge([
            'pageName'   => 'Untitled', // Default page name
            'buttonName' => 'Page Break', // Sidebar button label
            'buttonPosition' => 10
        ], $settings);
    }

    /**
     * Renders the module inside the canvas.
     */
    public function render() {
        ob_start();
        ?>
        <div class="module-preview page-break-module" data-module="PageBreakModule" data-module-id="<?php echo esc($this->instanceId); ?>">
            <div class="page-break-content">
                <div class="page-break-line"></div>
                <div class="page-number">
                    Page (<span class="dynamic-page-number">#</span>) - Page Name: <span class="dynamic-page-name"><?php echo esc($this->settings['pageName']); ?></span>
                </div>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }

    /**
     * Renders the button in the sidebar for adding this module.
     */
    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="PageBreakModule">' . esc($this->settings['buttonName']) . '</button>';
    }

    /**
     * Renders the settings UI when the module is selected.
     */
    public function renderSettings() {
        ob_start(); ?>
        <div class="form-group">
            <label for="pageName">Page Name:</label>
            <input type="text" id="pageName" value="<?php echo esc($this->settings['pageName']); ?>">
        </div>
        <?php
        return ob_get_clean();
    }
}
?>
