<?php
/*
Module Name: Text Box
Module Type: layout
Settings:
    label: text
    content: wysiwyg
    marginTop: number
    marginRight: number
    marginBottom: number
    marginLeft: number
    paddingTop: number
    paddingRight: number
    paddingBottom: number
    paddingLeft: number
*/

// Ensure default values if not provided.
if (!isset($settings)) { $settings = []; }
if (!isset($instanceId)) { $instanceId = ''; }

// Set default values
$defaultLabel   = isset($settings['label']) ? $settings['label'] : '';
$defaultContent = isset($settings['content']) ? $settings['content'] : 'This is a text box. Content will be displayed here.';
$marginTop      = isset($settings['marginTop']) ? $settings['marginTop'] : 0;
$marginRight    = isset($settings['marginRight']) ? $settings['marginRight'] : 0;
$marginBottom   = isset($settings['marginBottom']) ? $settings['marginBottom'] : 0;
$marginLeft     = isset($settings['marginLeft']) ? $settings['marginLeft'] : 0;
$paddingTop     = isset($settings['paddingTop']) ? $settings['paddingTop'] : 0;
$paddingRight   = isset($settings['paddingRight']) ? $settings['paddingRight'] : 0;
$paddingBottom  = isset($settings['paddingBottom']) ? $settings['paddingBottom'] : 0;
$paddingLeft    = isset($settings['paddingLeft']) ? $settings['paddingLeft'] : 0;
?>

<div class="text-box-module" id="<?= esc($instanceId) ?>"
    style="margin: <?= esc($marginTop) ?>px auto <?= esc($marginBottom) ?>px auto;
           padding: <?= esc($paddingTop) ?>px <?= esc($paddingRight) ?>px <?= esc($paddingBottom) ?>px <?= esc($paddingLeft) ?>px;">
    
    <!-- Label (Hidden if not set) -->
    <?php if (!empty($defaultLabel)) : ?>
        <label class="text-box-label"><?= esc($defaultLabel) ?></label>
    <?php endif; ?>

    <!-- Display Content (Formatted from TinyMCE) -->
    <div class="text-box-content">
        <?= $defaultContent ?>
    </div>
</div>

<style>
.text-box-module {
    max-width: 800px;
    text-align: center;
    background: transparent; /* No border */
}

.text-box-label {
    font-weight: bold;
    display: block;
    margin-bottom: 5px;
}

.text-box-content {
    font-size: 16px;
    line-height: 1.5;
    text-align: center;
}
</style>

<?php if (isset($isSettingsPanel) && $isSettingsPanel): ?>
    <!-- Load TinyMCE for the Settings Panel -->
    <script src="/js/tinymce/tinymce.min.js"></script>
    <script>
    document.addEventListener("DOMContentLoaded", function () {
        tinymce.init({
            selector: '[name="settings[content]"]',
            height: 300,
            menubar: false,
            plugins: 'advlist autolink lists link charmap preview anchor',
            toolbar: 'undo redo | bold italic | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent',
            content_css: '/js/tinymce/skins/content/default'
        });
    });
    </script>
<?php endif; ?>
