document.addEventListener('DOMContentLoaded', function() {
  
  const canvas = document.getElementById('canvas');
  const settingsPanel = document.querySelector('.settings');

  // Helper function to clear the selection state from all modules
  function clearSelections() {
    document.querySelectorAll('.module-preview').forEach(mod => mod.classList.remove('selected'));
  }

  // Function to load module settings from pre-defined PHP markup
  function loadModuleSettings(module, moduleType) {
    settingsPanel.innerHTML = ''; // Clear existing settings content

    const settingsHTML = moduleSettingsMarkup[moduleType];

    if (settingsHTML) {
      // If settings HTML is defined, load into the panel
      settingsPanel.innerHTML = `
        <h2>Module Settings</h2>
        ${settingsHTML}
        <button id="save-module-settings">Update Module</button>
      `;

      // Event listener to update module when settings are changed
      document.getElementById('save-module-settings').onclick = function() {
        updateModuleFromSettings(module, moduleType);
      };
    } else {
      // No settings available for this module
      settingsPanel.innerHTML = '<h2>No settings defined for this module.</h2>';
    }
  }

  // Handle clicks on modules within the canvas area using event delegation
  canvas.addEventListener('click', function(e) {
    const clickedModule = e.target.closest('.module-preview');

    if (clickedModule) {
      clearSelections();
      clickedModule.classList.add('selected');

      const moduleType = clickedModule.getAttribute('data-module');

      // Load settings specific to the clicked module
      loadModuleSettings(clickedModule, moduleType);
    }
  });

  // Function to update the module's displayed content based on settings changes
  function updateModuleFromSettings(module, moduleType) {
    if (moduleType === 'PageBreakModule') {
      const pageLabel = document.getElementById('pageLabel').value;
      module.querySelector('.page-number').innerHTML = `${pageLabel} <span class="dynamic-page-number">#</span>`;
    }

    if (moduleType === 'TitlePageModule') {
      module.querySelector('h1').innerText = document.getElementById('module-title').value;
      module.querySelector('h2').innerText = document.getElementById('module-subtitle').value;
      module.querySelector('h3').innerText = document.getElementById('module-author').value;
    }

    // Include similar updates for other modules as needed
  }

  // Initially clear the settings panel on load
  settingsPanel.innerHTML = '<h2>Module Settings</h2><p>Select a module to edit its settings.</p>';

});
